==> activity-common-api-1.3.33-sources.jar: cn/com/duiba/activity/common/center/api/dto/activity/OperatingActivityDto.java <==
package cn.com.duiba.activity.common.center.api.dto.activity;

import cn.com.duiba.activity.common.center.api.dto.BaseActivityDto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gey on 2018/3/7. 活动入库dto
 */
public class OperatingActivityDto extends BaseActivityDto implements Serializable{

    private static final long serialVersionUID = -1137126468254229534L;
    private Long id;
    //appId
    private Long appId;
    //标题
    private String title;
    //活动类型
    private Integer type;
    //数据状态  引用：StatusInt*
    private Integer status;
    //首页bannerID
    private Long appBannerId;
    //兑换项ID
    private Long appItemId;
    // 消耗积分数
    private Long credits;
    // 每日最多几次
    private Integer limitCount;
    // 每日免费次数
    private Integer freeLimit;
    // 活动规则
    private String rule;
    // 主图
    private String image;
    //缩略图
    private String smallImage;
    //小图标
    private String logo;
    //banner
    private String bannerImage;
    //引用活动ID,  如：兑吧专题活动，兑吧单品抽奖，兑吧大转盘.....
    private Long activityId;
    //秒杀活动  使用这个字段
    private Long parentActivityId;
    // 是否已经删除
    private Boolean deleted;
    //积分模式
    private Integer creditsType;
    //活动模版
    private String subType;
    //免费参数次数限制类型
    private String freeScope;
    //参与次数限制类型
    private String limitScope;
    // 概率说明
    private String rateIntroduction;
    // 抽奖积分-自定义
    private Long customCredits;
    //商品防刷
    private String exchangeLimit;
    //位运算
    private Integer switches;
    // 自动下架时间
    private Date autoOffDate;
    //是否对开发者隐藏
    private Boolean hiddenForDeveloper;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getAppBannerId() {
        return appBannerId;
    }

    public void setAppBannerId(Long appBannerId) {
        this.appBannerId = appBannerId;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }

    public Integer getFreeLimit() {
        return freeLimit;
    }

    public void setFreeLimit(Integer freeLimit) {
        this.freeLimit = freeLimit;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getParentActivityId() {
        return parentActivityId;
    }

    public void setParentActivityId(Long parentActivityId) {
        this.parentActivityId = parentActivityId;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Integer getCreditsType() {
        return creditsType;
    }

    public void setCreditsType(Integer creditsType) {
        this.creditsType = creditsType;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getFreeScope() {
        return freeScope;
    }

    public void setFreeScope(String freeScope) {
        this.freeScope = freeScope;
    }

    public String getLimitScope() {
        return limitScope;
    }

    public void setLimitScope(String limitScope) {
        this.limitScope = limitScope;
    }

    public String getRateIntroduction() {
        return rateIntroduction;
    }

    public void setRateIntroduction(String rateIntroduction) {
        this.rateIntroduction = rateIntroduction;
    }

    public Long getCustomCredits() {
        return customCredits;
    }

    public void setCustomCredits(Long customCredits) {
        this.customCredits = customCredits;
    }

    public String getExchangeLimit() {
        return exchangeLimit;
    }

    public void setExchangeLimit(String exchangeLimit) {
        this.exchangeLimit = exchangeLimit;
    }

    public Integer getSwitches() {
        return switches;
    }

    public void setSwitches(Integer switches) {
        this.switches = switches;
    }

    public Date getAutoOffDate() {
        return autoOffDate;
    }

    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    public Boolean getHiddenForDeveloper() {
        return hiddenForDeveloper;
    }

    public void setHiddenForDeveloper(Boolean hiddenForDeveloper) {
        this.hiddenForDeveloper = hiddenForDeveloper;
    }
}

==> activity-common-api-1.4.31-sources.jar: cn/com/duiba/activity/common/center/api/dto/activity/OperatingActivityDto.java <==
package cn.com.duiba.activity.common.center.api.dto.activity;

import cn.com.duiba.activity.common.center.api.dto.BaseActivityDto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gey on 2018/3/7. 活动入库dto
 */
public class OperatingActivityDto extends BaseActivityDto implements Serializable{

    private static final long serialVersionUID = -1137126468254229534L;
    private Long id;
    //appId
    private Long appId;
    //标题
    private String title;
    //活动类型
    private Integer type;
    //数据状态  引用：StatusInt*
    private Integer status;
    //首页bannerID
    private Long appBannerId;
    //兑换项ID
    private Long appItemId;
    // 消耗积分数
    private Long credits;
    // 每日最多几次
    private Integer limitCount;
    // 每日免费次数
    private Integer freeLimit;
    // 活动规则
    private String rule;
    // 主图
    private String image;
    //缩略图
    private String smallImage;
    //小图标
    private String logo;
    //banner
    private String bannerImage;
    //引用活动ID,  如：兑吧专题活动，兑吧单品抽奖，兑吧大转盘.....
    private Long activityId;
    //秒杀活动  使用这个字段
    private Long parentActivityId;
    // 是否已经删除
    private Boolean deleted;
    //积分模式
    private Integer creditsType;
    //活动模版
    private String subType;
    //免费参数次数限制类型
    private String freeScope;
    //参与次数限制类型
    private String limitScope;
    // 概率说明
    private String rateIntroduction;
    // 抽奖积分-自定义
    private Long customCredits;
    //商品防刷
    private String exchangeLimit;
    //位运算
    private Integer switches;
    //开始时间
    private Date startTime;
    // 自动下架时间
    private Date autoOffDate;
    //是否对开发者隐藏
    private Boolean hiddenForDeveloper;
    //扩展内容
    private String extendJson;

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getAppBannerId() {
        return appBannerId;
    }

    public void setAppBannerId(Long appBannerId) {
        this.appBannerId = appBannerId;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }

    public Integer getFreeLimit() {
        return freeLimit;
    }

    public void setFreeLimit(Integer freeLimit) {
        this.freeLimit = freeLimit;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getParentActivityId() {
        return parentActivityId;
    }

    public void setParentActivityId(Long parentActivityId) {
        this.parentActivityId = parentActivityId;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Integer getCreditsType() {
        return creditsType;
    }

    public void setCreditsType(Integer creditsType) {
        this.creditsType = creditsType;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getFreeScope() {
        return freeScope;
    }

    public void setFreeScope(String freeScope) {
        this.freeScope = freeScope;
    }

    public String getLimitScope() {
        return limitScope;
    }

    public void setLimitScope(String limitScope) {
        this.limitScope = limitScope;
    }

    public String getRateIntroduction() {
        return rateIntroduction;
    }

    public void setRateIntroduction(String rateIntroduction) {
        this.rateIntroduction = rateIntroduction;
    }

    public Long getCustomCredits() {
        return customCredits;
    }

    public void setCustomCredits(Long customCredits) {
        this.customCredits = customCredits;
    }

    public String getExchangeLimit() {
        return exchangeLimit;
    }

    public void setExchangeLimit(String exchangeLimit) {
        this.exchangeLimit = exchangeLimit;
    }

    public Integer getSwitches() {
        return switches;
    }

    public void setSwitches(Integer switches) {
        this.switches = switches;
    }

    public Date getAutoOffDate() {
        return autoOffDate;
    }

    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }

    public Boolean getHiddenForDeveloper() {
        return hiddenForDeveloper;
    }

    public void setHiddenForDeveloper(Boolean hiddenForDeveloper) {
        this.hiddenForDeveloper = hiddenForDeveloper;
    }

    public String getExtendJson() {
        return extendJson;
    }

    public void setExtendJson(String extendJson) {
        this.extendJson = extendJson;
    }
}
